<?php
/**
 * Includes the main Class of the Plugin.
 * 
 * ******************************************************************************************************
 * IMPORTANT: In registerPublic() line 134: Please keep plugin version # up to date for cache busting.  *
 * ******************************************************************************************************
 *
 * @filesource
 * @author Stefan Herndler
 * @since 1.5.0 12.09.14 10:56
 * 
 * Edited for v1.6.5: Replaced deprecated function create_function()
 * Edited for v2.0.0: Added jQueryUI from Cloudflare   2020-10-26T1907+0100
 * Edited for v2.0.3: Added style sheet versioning   2020-10-29T1413+0100
 * Edited for v2.0.4: Added jQuery UI from WordPress   2020-11-01T1902+0100
 * 
 * Continual update of version number.
 */


/**
 * Entry point of the Plugin. Loads the Dashboard and executes the Task.
 *
 * @author Stefan Herndler
 * @since 1.5.0
 */
class MCI_Footnotes {

    /**
     * Reference to the Plugin Task object.
     *
     * @author Stefan Herndler
     * @since 1.5.0
     * @var null|MCI_Footnotes_Task
     */
    public $a_obj_Task = null;

    /**
     * Executes the Plugin.
     *
     * @author Stefan Herndler
     * @since 1.5.0
     */
    public function run() {
            // register language
        MCI_Footnotes_Language::registerHooks();
        // register Button hooks
        MCI_Footnotes_WYSIWYG::registerHooks();
        // register general hooks
        MCI_Footnotes_Hooks::registerHooks();
        
        // initialize the Plugin Dashboard
        $this->initializeDashboard();
        // initialize the Plugin Task
        $this->initializeTask();
        
        // Register all Public Stylesheets and Scripts
        add_action('init', array($this, 'registerPublic'));
        // Enqueue all Public Stylesheets and Scripts
        add_action('wp_enqueue_scripts', array($this, 'registerPublic'));
        // Register all Widgets of the Plugin.
        add_action('widgets_init', array($this, 'initializeWidgets'));
    }

    /**
     * Initializes all Widgets of the Plugin.
     *
     * @author Stefan Herndler
     * @since 1.5.0
     * 
     * Edited for 1.6.5: replaced deprecated function create_function()
     * 
     * Contributed by Felipe Lavín Z.   Thankfully acknowledged.
     * 
     * create_function() was deprecated in PHP 7.2:
     * <https://wordpress.org/support/topic/deprecated-in-php-7-2-function-create_function-is-deprecated/>
     * See also: <https://wordpress.org/support/topic/deprecated-function-create_function-14/>
     */
    public function initializeWidgets() {
      register_widget("MCI_Footnotes_Widget_ReferenceContainer");
    }

    /**
     * Initializes the Dashboard of the Plugin and loads them.
     *
     * @author Stefan Herndler
     * @since 1.5.0
     */
    private function initializeDashboard() {
        new MCI_Footnotes_Layout_Init();
    }

    /**
     * Initializes the Plugin Task and registers the Task hooks.
     *
     * @author Stefan Herndler
     * @since 1.5.0
     */
    private function initializeTask() {
        $this->a_obj_Task = new MCI_Footnotes_Task();
        $this->a_obj_Task->registerHooks();
    }

    /**
     * Registers and enqueues scripts and stylesheets to the public pages.
     *
     * @author Stefan Herndler
     * @since 1.5.0
     * 
     * Updated for v2.0.0 adding jQuery UI
     * Updated for v2.0.4 by adding jQuery UI from WordPress following @check2020de:
     * <https://wordpress.org/support/topic/gdpr-issue-with-jquery/>
     * See <https://wordpress.stackexchange.com/questions/273986/correct-way-to-enqueue-jquery-ui>
     * 
     * jQueryUI re-enables the tooltip infobox disabled when WPv5.5 was released.
     */
    public function registerPublic() {

        ###  SCRIPTS

        // add the jQuery plugin registered by WordPress
        wp_enqueue_script( 'jquery' );

        // Add jQuery Tools:
        wp_enqueue_script('mci-footnotes-js-jquery-tools', plugins_url('../js/jquery.tools.min.js', __FILE__));

        // Add the jQuery UI libraries registered by WordPress:
        // 'no need to enqueue -core, because dependencies are set'
        // Source: <https://wordpress.stackexchange.com/questions/273986/correct-way-to-enqueue-jquery-ui>
        wp_enqueue_script( 'jquery-ui-widget' );
        wp_enqueue_script( 'jquery-ui-mouse' );
        wp_enqueue_script( 'jquery-ui-accordion' );
        wp_enqueue_script( 'jquery-ui-autocomplete' );
        wp_enqueue_script( 'jquery-ui-slider' );


        // Should that not work, fetch jQuery UI from cdnjs.cloudflare.com:
        // Add jQuery UI following @vonpiernik:
        // <https://wordpress.org/support/topic/tooltip-hover-not-showing/#post-13456762>:
        // This was enabled in Footnotes v2.0.0 through v2.0.3.
        // Re-added for 2.0.9d1 to look whether it can fix a broken tooltip display.   2020-11-07T1601+0100
        //wp_register_script( 'jQueryUI', 'https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js', null, null, true );
        //wp_enqueue_script( 'jQueryUI' );

        // Add jQuery Tools and finish adding jQueryUI:   2020-11-08T1638+0100
        //wp_enqueue_script('mci-footnotes-js-jquery-tools', plugins_url('../js/jquery.tools.min.js', __FILE__), ['jQueryUI']);

        
        ###  STYLES
        
        // IMPORTANT: up-to-date plugin version number NEEDED for cache busting:
        wp_enqueue_style(
            'mci-footnotes-css-public',
            plugins_url('../css/public.css', __FILE__),
            '',
            '2.1.0'
        );
    }
    
}
